<?php

/*
Plugin Name: PiwikSearchEngineKeywords
 
Plugin URI: http://www.virtual-maxim.de/piwiksearchenginekeywords/
Description: Displays incoming queries from search engines like Google.
Version: 0.3.1
Author: Maxim
Author URI: http://www.virtual-maxim.de

*/




/*
 * Options in WP database (Name: __CLASS__):
 *
 * showbox - is output box visible? (1/0)
 * widgettitle - title of widget box
 * postboxtitle - title of output box in a post
 * keywordslimit - number of maximum keywords in output box
 * configfile - path to piwik configuration file (config.ini.php)
 * nocss - do not include css-file
 * linkson - show keywords as links
 * separator - keywords separator
 * utf8 - utf-8 database request
*/

//define('WP_DEBUG', true);



/**
 *  define class if not exists
 */
if ( !class_exists('PiwikSearchEngineKeywords') )
{
    /**
     *  Plugin class
     *
     */
    class PiwikSearchEngineKeywords
    {
        private $mysqlHost;
        private $mysqlUser;
        private $mysqlPass;
        private $mysqlDBname;
        private $piwikPrefix;

        private $PluginDir;

        private $keywordsLimit;
        private $outputBoxTitle;
        private $noCSS;
        private $showBox;
        private $showAsLinks;
        private $separator;
        private $utf8;

        /**
         * Constructor
         *
         */
        public function __construct()
        {
            // set plugin path
            $this->PluginDir = WP_PLUGIN_URL.'/'.dirname(plugin_basename(__FILE__));

            load_plugin_textdomain('psek', false, dirname(plugin_basename(__FILE__)) . '/languages' );

            $options = get_option(__CLASS__);
            $this->keywordsLimit = $options['keywordslimit'];
            $this->outputBoxTitle = $options['postboxtitle'];
            $this->noCSS = $options['nocss'];
            $this->showBox = $options['showbox'];
            $this->showAsLinks = $options['linkson'];
            $this->separator = $options['separator'];
            $this->utf8 = $options['utf8'];

            // read access data for mysql database from piwik configuration file
            if($options['configfile'] != "")
            {
                $iniArray = @parse_ini_file($options['configfile']);
                if($iniArray == "")
                    $this->ShowMessage(0);
                else
                {
                    $this->mysqlHost = $iniArray['host'];
                    $this->mysqlUser = $iniArray['username'];
                    $this->mysqlPass = $iniArray['password'];
                    $this->mysqlDBname = $iniArray['dbname'];
                    $this->piwikPrefix = $iniArray['tables_prefix'];
                }
            }
            else
                $this->ShowMessage(0);

            register_activation_hook(__FILE__, array($this, 'Install'));

            add_action('widgets_init', array($this, 'ActivateWidget'));

            add_action('admin_menu', array($this, 'AddMenu'));

            if((int)($this->noCSS) == 0)
                add_action('wp_head', array($this, 'IncludeCSS'));

            add_filter('the_content', array($this, 'ShowKeywords'));
        }

        function Message_0()
        {
            echo "<br /><div id='psek_warning' class='updated'><p><strong>".__('PiwikSEK is not ready','psek').":</strong> ".__('Set the path to Piwik configuration file','psek').'.</p></div>';
        }
        function Message_1()
        {
            echo "<br /><div id='psek_warning' class='updated fade'><p>".__('Settings saved','psek').'.</p></div>';
        }


        private function ShowMessage($msg_nr)
        {
            add_action('admin_notices', array($this, ('Message_'.$msg_nr)));
        }

        /**
         *  Include CSS-file in wordpress-head
         *  @return string
         */
        function IncludeCSS()
        {
            echo '<link type="text/css" rel="stylesheet" href="'.$this->PluginDir.'/style.css" />';
        }

        /**
         *  Register widget
         */
        public function ActivateWidget()
        {
            if (function_exists('register_sidebar_widget') )
            {
                register_sidebar_widget(array( __CLASS__, 'widgets'), array($this, 'WidgetOutput'));
                register_widget_control(array( __CLASS__, 'widgets'), array($this, 'WidgetControl'), 300, 150);
            }
        }

        public function Install()
        {
            $options = array();
            $options['showbox'] = 0;
            $options['nocss'] = 0;
            $options['linkson'] = 0;
            $options['keywordslimit'] = 10;
            $options['configfile'] = "";
            $options['separator'] = "";
            $options['postboxtitle'] = __('Visitors who have found this post, looking for:','psek');
            $options['utf8'] = 0;

            add_option(__CLASS__, $options);
        }

        public function AddMenu()
        {
            add_options_page('PiwikSEK '.__('Settings','psek'),'PiwikSEK', 9, __FILE__, array($this, 'OptionPage'));
        }


        /**
         * Connect to MySQL-database.
         *
         * @return mysql_connection
         */
        private function GetDatabaseConnection()
        {
            if($this->mysqlHost == "")
                return null;

            $con = @mysql_connect($this->mysqlHost, $this->mysqlUser, $this->mysqlPass, true)
                    or die(__('No connection to MySQL','psek'). mysql_error());

            // UTF-8 request
            if($this->utf8 == 1)
                @mysql_query("SET NAMES 'utf8'", $con);

            @mysql_select_db($this->mysqlDBname) or die(__('Database not found','psek'). mysql_error());

            return $con;
        }

        /**
         *
         * @return string
         */
        private function GetKeywords($separator_on = false)
        {
            $db = $this->GetDatabaseConnection();

            if($db==null)
                return "";

            $url = 'http://'.$_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI'];
            //$url = 'http://www.virtual-maxim.de/ini-dateien-lesen-schreiben/';
            // echo $url;

            // ID der Action bestimmen
            $query = "SELECT idaction FROM ".$this->piwikPrefix."log_action WHERE name='".$url."' LIMIT 1;";
            $result = @mysql_query($query, $db) OR die(__("Could not execute query"). mysql_error());

            $keywords = "";
            $keywordsnum = mysql_num_rows($result);
            if($keywordsnum > 0)
            {
                $data = mysql_fetch_array($result);
                $actionid = $data[0];

                $query = "SELECT referer_keyword,referer_url FROM ".$this->piwikPrefix."log_visit WHERE visit_entry_idaction_url='".$actionid."' AND referer_keyword!='' GROUP BY referer_keyword  LIMIT ".$this->keywordsLimit.";";
                $result = @mysql_query($query, $db) OR die(__("Could not execute query"). mysql_error());

                $counter = 0;
                while($ent = mysql_fetch_array($result))
                {
                    $keyword = $ent[0];

                    // show keyword as a link
                    if((int)($this->showAsLinks) == 1)
                        $keyword = '<a href="'.$ent[1].'" >'.$ent[0].'</a>';

                    // last keyword dont need a separator
                    if($counter != $keywordsnum)
                        $keywords = $keywords.'<li>'.$keyword.'</li>'.(($separator_on==true && $this->separator!="") ? '<li class="psek_separator">'.$this->separator.'</li>' : '');
                    else
                        $keywords = $keywords.'<li>'.$keyword.'</li>';

                    $counter++;
                }
            }

            mysql_close($db);

            return $keywords;
        }

        /**
         * Show keywords in a <div>-area
         *
         * @param <type> $content
         * @return <type>
         */
        function ShowKeywords($content)
        {

            $output = '';
            if (is_single() && (int)($this->showBox)==1)
            {
                $keywords = $this->GetKeywords(true);

                if($keywords != "")
                {
                    $output = '<div class="psek_post_out" ><p>'.$this->outputBoxTitle.'</p><ul>'.$keywords.'</ul></div>';
                }
            }
            return $content.$output;
        }

        /**
         *  Widget output. Show keywords in a <div>-area
         *
         * @param <type> $args
         * @return string
         */
        function WidgetOutput($args)
        {
            if (is_single())
            {
                $keywords = $this->GetKeywords();

                if($keywords == "")
                    return;

                extract($args);

                $options = get_option(__CLASS__);
                $title = $options['widgettitle'];

                echo $before_widget . $before_title . $title . $after_title;
                echo '<div class="psek_widget_out"><ul>'.$keywords.'</ul></div>';
                echo $after_widget;
            }
        }

        /**
         * Widget control menu
         */
        function WidgetControl()
        {
            $options = get_option(__CLASS__);
            if ( $_POST['PSEK-widgetsubmit'] )
            {
                $options['widgettitle'] = strip_tags(stripslashes($_POST['PSEK-widgettitle']));
                update_option(__CLASS__, $options);
            }

            $widgettitle = htmlspecialchars($options['widgettitle'], ENT_QUOTES);
            echo '<p style="text-align:right;"><label for="PSEK-widgettitle">' . __('Title', 'psek') . ': <input style="width: 200px;" id="PSEK-widgettitle" name="PSEK-widgettitle" type="text" value="'.$widgettitle.'" /></label></p>';
            echo '<input type="hidden" id="PSEK-widgetsubmit" name="PSEK-widgetsubmit" value="1" />';
        }

        /**
         * Show plugins options
         */
        function OptionPage()
        {
            $options = get_option(__CLASS__);
            if ($_POST['PSEK-optionssubmit'] )
            {
                $options['showbox'] = $_POST['PSEK-showbox'];
                $options['nocss'] = $_POST['PSEK-nocss'];
                $options['linkson'] = $_POST['PSEK-linkson'];
                $options['utf8'] = $_POST['PSEK-utf8'];
                $options['keywordslimit'] = htmlspecialchars($_POST['PSEK-keywordslimit'], ENT_QUOTES);
                $options['configfile'] = htmlspecialchars($_POST['PSEK-configfile'], ENT_QUOTES);
                $options['postboxtitle'] = htmlspecialchars($_POST['PSEK-postboxtitle'], ENT_QUOTES);
                $options['separator'] = htmlspecialchars($_POST['PSEK-separator'], ENT_QUOTES);

                update_option(__CLASS__, $options);

               
            }

            echo '<div style="width:170px; float: right; margin: 8px;">
                <div style="border:1px solid #000; width:170px; padding: 0 8px 8px 8px;">
                  <h3>'.__('Donation','psek').'</h3>
                  <p>'.__('If you like PiwikSEK, you can help the development with a donation or gift.','psek').'</p>
                    <form action="https://www.paypal.com/cgi-bin/webscr" method="post">
                    <input type="hidden" name="cmd" value="_s-xclick" />
                    <input type="hidden" name="hosted_button_id" value="W583B3ATYTACW" />
                    <input type="image" src="https://www.paypal.com/de_DE/DE/i/btn/btn_donate_SM.gif" name="submit" alt="Jetzt einfach, schnell und sicher online bezahlen  mit PayPal." />
                    <img alt="pixel"  src="https://www.paypal.com/de_DE/i/scr/pixel.gif" width="1" height="1" /></form>
                    <hr>
                    <a alt="Amazon Wishlist" href="http://www.amazon.de/registry/wishlist/2XHCAF5KVO61D/">'.__('My Amazon.de wishlist','psek').'</a>
                  </div>
                  <div style="border:1px solid #000; width:170px; margin-top:5px; padding: 0 8px 8px 8px;">
                  <h3>'.__('Contact','psek').'</h3>
                  <a alt="Project page" href="http://www.virtual-maxim.de/piwiksearchenginekeywords/">'.__('Project page','psek').'</a>

                      
                   </div>
                  </div>

                        <h3 ><span>PiwikSEK '.__('Settings','psek').'</span></h3>
                       
                        <form name="psek_form" method="post" action="">
                        <label for="PSEK-configfile">'.__('Path to config.ini.php','psek').':</label>
                        <input type="text" size="100" id="PSEK-configfile" name="PSEK-configfile" value="'.(($options['configfile']=="") ? $_SERVER['DOCUMENT_ROOT'].'/piwik/config/config.ini.php' : $options['configfile']).'" /> <br />
                        
                        <label for="PSEK-showbox">'.__('Output box in posts?','psek').'</label>
                        <input type="checkbox" name="PSEK-showbox" id="PSEK-showbox" value="1" '.(($options['showbox']=="1") ? 'checked="checked"' : "").' /><br />
                        <label for="PSEK-nocss">'.__('Exclude CSS file?','psek').'</label>
                        <input type="checkbox" name="PSEK-nocss" id="PSEK-nocss" value="1" '.(($options['nocss']=="1") ? 'checked="checked"' : "").' /><br />
                        <label for="PSEK-linkson">'.__('Show keywords as links?','psek').'</label>
                        <input type="checkbox" name="PSEK-linkson" id="PSEK-linkson" value="1" '.(($options['linkson']=="1") ? 'checked="checked"' : "").' /><br />


                        <label for="PSEK-keywordslimit">'.__('Number of keywords','psek').':</label>
                        <input type="text" maxlength="2" size="2" id="PSEK-keywordslimit" name="PSEK-keywordslimit" value="'.$options['keywordslimit'].'" /> <br />
                        <label for="PSEK-postboxtitle">'.__('Title of output box','psek').':</label>
                        <input type="text" size="100" id="PSEK-postboxtitle" name="PSEK-postboxtitle" value="'.$options['postboxtitle'].'" /> <br />

                        <label for="PSEK-separator">'.__('Keywords separator','psek').':</label>
                        <input type="text" size="10" id="PSEK-separator" name="PSEK-separator" value="'.$options['separator'].'" /> <br />

                        <label for="PSEK-utf8">'.__('UTF-8 database request?','psek').'</label>
                        <input type="checkbox" name="PSEK-utf8" id="PSEK-utf8" value="1" '.(($options['utf8']=="1") ? 'checked="checked"' : "").' /><br />


                        <input type="submit" value="'.__('Save','psek').'" name="PSEK-optionssubmit" />
                    </form>
                    
                  ';


        }

    }


}

// create a new instance of plugin class
if ( class_exists('PiwikSearchEngineKeywords') )
{
    new PiwikSearchEngineKeywords();
}


?>